#!/bin/ksh

# inputs are product code, action and instance name (None for no instance)
if [ $# -lt 3 ] ; then
   echo "Usage: agentInstanceCommand.sh prodcode STATUS/START/STOP instance [user]"
   exit 1
fi 

# if [ $1 != "um" ] ; then
#   echo "Usage: only product code um is current supported"	
#   exit 1
# fi

# Returns 
# 0 if success, that is the STATUS is running or START or STOP commands completed successfully
# 1 if failure


STATUS="STATUS"
START="START"
STOP="STOP"

# set CANDLEHOME - this script is installed in $CANDLEHOME/$ITM_BINARCH/lz/bin
# Get the script path
THIS_DIR=`dirname $0`
# Set CANDLEHOME
CANDLEHOME=`cd $THIS_DIR/../../.. && pwd`

# verify is environment is set to a valid dir
if [ -d "$CANDLEHOME" ] ; then
   echo "$CANDLEHOME" 
else
   echo "Usage: CANDLEHOME not valid"
   exit 1
fi

# test command
if [ $2 = $STATUS ] ; then
   if [ $1 = "ud" ] ; then
      UMINSTANCE=`$CANDLEHOME/bin/cinfo -r | grep -w $1 | grep "\.running" | sed "s/_/ /" | grep -w $3 | awk '{ print $7 }' | grep -w $3`
   else
      UMINSTANCE=`$CANDLEHOME/bin/cinfo -r | grep -w $1 | grep "\.running" | awk '{print $2 " " $6}' | grep -w $1 | grep -w $3 | awk '{print $2}'`
   fi
   if [ "$UMINSTANCE" = $3 ] ; then
      echo "Found running instance $3"
      exit 0
   fi
elif [ $2 = $START ] ; then
   if [[ ( $3 = "None" ) && ( $1 = "um" || $1 = "mq" ) ]] ; then
      START_CMD="$CANDLEHOME/bin/itmcmd agent start $1"
   elif [ $1 = "um" ] ; then
      START_CMD="$CANDLEHOME/bin/itmcmd agent -p $3 start $1"
   else
      START_CMD="$CANDLEHOME/bin/itmcmd agent -o $3 start $1"
   fi
   if [ -z "$4" ] ; then
      $START_CMD
   else
      su - $4 -c "$START_CMD"
   fi
   startresult=$?
	echo "Start result: $startresult"
   if [[ $startresult -eq 0 || $startresult -eq 2 ]] ; then
	exit 0
   fi
elif [ $2 = $STOP ] ; then
   if [[ ( $3 = "None" ) && ( $1 = "um" || $1 = "mq" ) ]] ; then
      STOP_CMD="$CANDLEHOME/bin/itmcmd agent stop $1"
   elif [ $1 = "um" ] ; then
      STOP_CMD="$CANDLEHOME/bin/itmcmd agent -p $3 stop $1"
   else
      STOP_CMD="$CANDLEHOME/bin/itmcmd agent -o $3 stop $1"
   fi
   if [ -z "$4" ] ; then
      $STOP_CMD
   else
      su - $4 -c "$STOP_CMD"
   fi
   stopresult=$?
   echo "Stop result: $stopresult"
   if [[ $stopresult -eq 0 || $stopresult -eq 2 ]] ; then
	exit 0
   fi
fi 

echo "$1 Command $2 failed"
exit 1

